subjob() computes one row of the virtual grid in a simulation
study, provides several seeding methods, and sub-job monitoring
(information about the sub-job just finished). printInfo is a named list of functions optionally to be used as
monitor in subjob() for printing information at the end of
each sub-job.
subjob(i, pGrid, nonGrids, n.sim, seed, keepSeed = FALSE,
repFirst = TRUE, doOne,
timer = mkTimer(gcFirst=FALSE), monitor = FALSE, ...)printInfo # or
# printInfo[["default"]]
i.sim and j
together determine i."grid", as returned by mkGrid().doOne()), i.e., typically
get.nonGrids(*)[["nonGrids"]].logical indicating if .Random.seed
should be appended to each return value of
doCallWE().function for computing one row in the
(physical) grid; must return a numeric vector, matrix, or array.function similar to
system.time(), passed to doCallWE().logical indicating whether a monitor
is displayed.doOne().simsalapar-package for
how to use these functions.doCallWE(); .Random.seed for information
about random number generators and seeds. For examples of implicit use of subjob, see
doLapply.